@@ -115,7 +115,7 @@ class KubeModel(ABC):
         """
         if os.path.isfile('opt.pkl'):
             self.logger.debug('Loading optimizer state')
-            with open('opt.pkl', 'rb') as f:
+            with open('test/opt.pkl', 'rb') as f:
                 state = pickle.load(f)
                 self.optimizer.load_state_dict(state)
 
@@ -134,7 +134,7 @@ class KubeModel(ABC):
         the following epochs
         """
         self.logger.debug('saving optimizer state')
-        with open('opt.pkl', 'wb') as f:
+        with open('test/opt.pkl', 'wb') as f:
             pickle.dump(self.optimizer.state_dict(), f)
         print('saved state')
 
@@ -292,6 +292,7 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
+        #self._load_optimizer_state()
 
         #self._reset_optimizer_state()
 
@@ -303,7 +304,7 @@ class KubeModel(ABC):
         self.__save_model()
         self._save_optimizer_redis()
         self._save_redis_test()
-
+        #self._save_optimizer_state()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
         """
